//@ts-check
"use strict";

/**
@typedef Weather
@type {{
  name: string;
  pixiRoot: PIXI.Container;
  fogSprite: PIXI.TilingSprite;
  fogOffset: number;
}}
*/

/** @returns {Weather} */
function createWeather() {
  const pixiRoot = new PIXI.Container();

  const fogSprite = new PIXI.TilingSprite(tex("inGame/weathers/fog"), 640, 360);;
  fogSprite.alpha = 0;
  fogSprite.visible = false;
  inGame.pixiRoot.addChild(fogSprite);

  return { name: "", pixiRoot, fogSprite, fogOffset: 0 };
}

/** @param {string} weatherName */
function ensureWeather(weatherName) {
  const { weather } = inGame;

  if (weather.name != weatherName) weather.name = weatherName;
}

function updateWeather(dt) {
  const { weather } = inGame;

  const targetFogAlpha = weather.name === "fog" ? 0.3 : 0;
  weather.fogSprite.alpha = lerp(weather.fogSprite.alpha, targetFogAlpha, dt);
  weather.fogSprite.visible = weather.fogSprite.alpha > 0;

  if (weather.fogSprite.visible) {
    weather.fogSprite.tilePosition.y = -inGame.camera.pos.y * tileSize;
    weather.fogOffset += dt * 10;
    weather.fogSprite.tilePosition.x = -inGame.camera.pos.x * tileSize + weather.fogOffset;
  }
}
